import io
import json
import logging
import os
from functools import cache as sync_cache
import httpx
import atexit
from typing import Optional, Union, BinaryIO
from fireworks.control_plane.generated.protos.gateway import (
    CreateDatasetRequest,
    ListDatasetsRequest,
    Dataset as DatasetProto,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.dataset_pb2 import (
    Dataset as SyncDataset,
    ListDatasetsRequest as SyncListDatasetsRequest,
    CreateDatasetRequest as SyncCreateDatasetRequest,
)
import mmh3


from fireworks.gateway import Gateway

logger = logging.getLogger(__name__)
handler = logging.StreamHandler()
formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
handler.setFormatter(formatter)
logger.addHandler(handler)
logger.propagate = False  # Prevent duplicate logs

if os.environ.get("FIREWORKS_SDK_DEBUG"):
    logger.setLevel(logging.DEBUG)


class Dataset:
    def __init__(
        self, api_key: Optional[str] = None, path: Optional[str] = None, data: Optional[Union[str, list]] = None
    ):
        """
        A "smart" Dataset class that helps developers upload datasets and
        fine-tune on Fireworks. It has the following features:

        1. Works nicely with the `fireworks.llm.LLM` class.
        2. Automatically names dataset based on the contents of the dataset and the filename of the file if provided.
        3. Automatically uploads dataset to Fireworks if it doesn't already exist.

        Args:
            path: Path to the local directory containing the dataset.
            data: Data to be uploaded to the dataset. Can be a string in JSONL format with OpenAI chat completion
                  message compatible JSON, or a list of OpenAI chat completion message compatible objects.
        TODO: support various remote paths to cloud storage.
        """
        self._data: Optional[str] = None
        self._path: Optional[str] = None
        self._gateway = Gateway(api_key=api_key)
        self._file_stream: Optional[BinaryIO] = None
        atexit.register(self._gateway._channel.close)

        if path and data:
            raise ValueError("Cannot provide both path and data")
        if not path and not data:
            raise ValueError("Must provide either path or data")
        if path and not path.endswith(".jsonl"):
            raise ValueError("File must be a JSONL file")

        if path:
            self._path = path
        elif isinstance(data, list):
            # Convert list to newline delimited JSON string
            self._data = "\n".join(json.dumps(item) for item in data)
        elif isinstance(data, str):
            self._data = data

    def get(self):
        """
        Get this dataset from Fireworks by hash
        - If filename of dataset changes, it still matches the hash
        """
        request = SyncListDatasetsRequest(page_size=1000)
        datasets = self._gateway.list_datasets_sync(request)
        for dataset in datasets:
            if str(hash(self)) in dataset.name:
                logger.debug(f"Found dataset with matching hash: {dataset.name}")
                return dataset
        logger.debug(f"No dataset found with matching hash: {hash(self)}")
        return None

    def sync(self):
        """
        Upload this dataset to Fireworks if it doesn't already exist.
        """
        # check if dataset exists by hash
        dataset = self.get()
        if dataset:
            logger.debug(f"Dataset already exists: {dataset.name}, no need to upload")
            return
        logger.debug(f"No dataset found with matching hash: {hash(self)}, creating new dataset")
        dataset = SyncDataset(
            format=self._detect_dataset_format(),
            example_count=min(self._line_count(), 50_000_000),
        )
        # upload dataset since it doesn't exist
        logger.debug(f"Creating dataset: {self.name}")
        request = SyncCreateDatasetRequest(dataset=dataset, dataset_id=self.name)
        dataset = self._gateway.create_dataset_sync(request)
        logger.debug(f"Dataset created: {dataset.name}")
        logger.debug(f"Uploading dataset: {self.name}")
        filename_to_size = {self.filename(): self.file_size()}
        signed_urls = self._gateway.get_dataset_upload_endpoint_sync(self.name, filename_to_size)
        self._upload_file_using_signed_url(signed_urls[self.filename()])
        logger.debug(f"Dataset uploaded: {self.name}")
        self._gateway.validate_dataset_sync(self.name)
        logger.debug(f"Dataset validated: {self.name}")

    def _upload_file_using_signed_url(self, signed_url: str) -> None:
        """
        Upload a file to a signed URL using async streaming to avoid loading the entire file into memory.

        Args:
            signed_url: The signed URL to upload the file to.
        """
        logger.debug(f"Uploading file to signed URL: {signed_url}")

        file = self._get_stream()
        try:
            # Get file size for content length
            file.seek(0, os.SEEK_END)
            size = file.tell()
            file.seek(0)

            # Prepare the HTTP request
            headers = {
                "Content-Type": "application/octet-stream",
                "X-Goog-Content-Length-Range": f"{size},{size}",
            }

            # Upload the file with streaming
            with httpx.Client() as client:
                response = client.put(signed_url, content=file, headers=headers)
                if response.status_code != 200:
                    raise RuntimeError(f"Failed to upload file: {response.status_code} - {response.text}")

            logger.debug("File upload completed successfully")
        finally:
            file.close()

    def filename(self) -> str:
        """
        Returns the filename of the dataset if path is provided, otherwise returns "inmemory"
        to indicate this dataset was created from an in-memory data structure rather than a file.
        """
        if self._path:
            return os.path.basename(self._path)
        return "inmemory.jsonl"

    @property
    def name(self):
        """
        Generates a name for this dataset in the form of "dataset-{hash(self)}-{filename}"
        """
        # remove ext from filename
        file_without_ext = os.path.splitext(self.filename())[0]
        return f"dataset-{hash(self)}-{file_without_ext}"

    @sync_cache
    def id(self):
        return self._id()

    def _id(self):
        account_id = self._gateway.account_id()
        return f"accounts/{account_id}/datasets/{self.name}"

    @property
    def stream(self) -> BinaryIO:
        """
        Returns a cached file-like object for the dataset content.
        For backward compatibility - prefer using get_stream() with a context manager.
        """
        if self._file_stream is not None and not self._file_stream.closed:
            self._file_stream.seek(0)
            return self._file_stream

        self._file_stream = self._get_stream()
        return self._file_stream

    def _line_count(self) -> int:
        """
        Returns the number of lines in the dataset
        """
        with self._get_stream() as stream:
            count = 0
            for _ in stream:
                count += 1
            return count

    def _detect_dataset_format(self) -> SyncDataset.Format:
        """
        Detects the format of the dataset by examining its content.

        Returns:
            A string representing the dataset format:
            - "CHAT" for chat completion format
            - "COMPLETION" for completion format
            - "FORMAT_UNSPECIFIED" if the format cannot be determined
        """

        try:
            with self._get_stream() as file:
                for line in file:
                    try:
                        data = json.loads(line.decode("utf-8"))

                        # Check for completion format (prompt + completion)
                        if "prompt" in data and "completion" in data:
                            return SyncDataset.Format.COMPLETION

                        # Check for chat format (messages array)
                        if "messages" in data and isinstance(data["messages"], list) and len(data["messages"]) > 0:
                            return SyncDataset.Format.CHAT

                        # If we reach here, the format doesn't match either completion or chat
                        return SyncDataset.Format.FORMAT_UNSPECIFIED
                    except json.JSONDecodeError:
                        return SyncDataset.Format.FORMAT_UNSPECIFIED

                # If we've read the entire file without determining a format, it's unspecified
                return SyncDataset.Format.FORMAT_UNSPECIFIED
        except Exception as e:
            logger.error(f"Error detecting dataset format: {e}")
            return SyncDataset.Format.FORMAT_UNSPECIFIED

    def _get_stream(self) -> BinaryIO:
        """
        Returns a fresh file-like object for the dataset content.
        For in-memory data, returns a BytesIO object.
        For file paths, returns a file object.
        This is intended to be used with a context manager to ensure proper cleanup.
        """
        if self._data:
            return io.BytesIO(self._data.encode("utf-8"))
        elif self._path:
            return open(self._path, "rb")
        else:
            raise ValueError("No data or path provided")

    def file_size(self) -> int:
        """
        Returns the size of the dataset in bytes without reading the entire file
        """
        # Use optimized path for files since we can get size without reading
        if self._path:
            return os.path.getsize(self._path)

        # For in-memory data, get the size from the stream
        with self._get_stream() as stream:
            stream.seek(0, io.SEEK_END)
            size = stream.tell()
            return size

    def __hash__(self) -> int:
        """
        Computes a hash of the dataset contents
        """
        # Read the entire file content for hashing
        content = self.read()
        # Ensure the hash is positive by using the unsigned value (& with MAXINT)
        return mmh3.hash(content) & 0x7FFFFFFF

    def __del__(self):
        """Clean up file handles when the object is destroyed"""
        if self._file_stream is not None and not self._file_stream.closed:
            self._file_stream.close()
        self._gateway._channel.close()

    def delete(self):
        """
        Delete this dataset from Fireworks
        """
        # if dataset doesn't exist, don't delete
        dataset = self.get()
        if not dataset:
            logger.debug(f"Dataset does not exist: {self.name}, no need to delete")
            return
        self._gateway.delete_dataset_sync(self.name)

    def read(self, size: Optional[int] = None) -> bytes:
        """
        Read content from the dataset

        Args:
            size: Number of bytes to read, or None to read the entire file
                 (use cautiously with large files)

        Returns:
            The content as bytes
        """
        with self._get_stream() as stream:
            if size is not None:
                return stream.read(size)
            return stream.read()



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class JobProgress(_message.Message):
    __slots__ = ("percent", "epoch")
    PERCENT_FIELD_NUMBER: _ClassVar[int]
    EPOCH_FIELD_NUMBER: _ClassVar[int]
    percent: int
    epoch: int
    def __init__(self, percent: _Optional[int] = ..., epoch: _Optional[int] = ...) -> None: ...



from pydantic import BaseModel, Field
from pydantic.types import StrictStr
from typing import Optional, List, Dict, Any, Union
import os

try:
    from typing import Literal
except ImportError:
    # should have been installed for Python3.7 and above
    from typing_extensions import Literal


# when running in a server environment, we want to error on extra fields
extra_policy = "forbid" if os.environ.get("FIREWORKS_API_STRICT") == "1" else "ignore"


class LogProbs(BaseModel, extra=extra_policy):
    tokens: List[str] = Field(default_factory=list)
    token_logprobs: List[float] = Field(default_factory=list)
    top_logprobs: Optional[List[Dict[str, float]]] = Field(default_factory=list)
    text_offset: List[int] = Field(default_factory=list)
    # Extension of OpenAI API: also return token ids
    token_ids: Optional[List[int]] = None


class NewLogProbsContentTopLogProbs(BaseModel, extra=extra_policy):
    token: str
    logprob: float
    token_id: int
    bytes: List[int] = Field(default_factory=list)


class NewLogProbsContent(BaseModel, extra=extra_policy):
    token: str
    logprob: float
    bytes: List[int]
    top_logprobs: List[NewLogProbsContentTopLogProbs] = Field(default_factory=list)
    token_id: int
    text_offset: int
    last_activation: Optional[str] = None


class NewLogProbs(BaseModel, extra=extra_policy):
    content: List[NewLogProbsContent] = Field(default_factory=list)


class UsageInfo(BaseModel, extra=extra_policy):
    """Usage statistics.

    Attributes:
      prompt_tokens (int): The number of tokens in the prompt.
      total_tokens (int): The total number of tokens used in the request (prompt + completion).
      completion_tokens (Optional[int]): The number of tokens in the generated completion.
    """

    prompt_tokens: int
    total_tokens: int
    completion_tokens: Optional[int] = None


class RawOutput(BaseModel, extra=extra_policy):
    """
    Extension of OpenAI that returns low-level interaction of what the model
    sees, including the formatted prompt and function calls
    """

    # Pieces of the prompt (like individual messages) before truncation and
    # concatenation. Depending on prompt_truncate_len some of the messages might
    # be dropped. Contains a mix of strings to be tokenized and individual
    # tokens (if dictated by the conversation template)
    prompt_fragments: List[Union[str, int]]
    # Fully processed prompt as seen by the model
    prompt_token_ids: List[int]
    # Raw completion produced by the model before any tool calls are parsed
    completion: str
    # Log probabilities for the completion. Only populated if logprobs is
    # specified in the request
    completion_logprobs: Optional[NewLogProbs] = None


class Choice(BaseModel, extra=extra_policy):
    """A completion choice.

    Attributes:
      index (int): The index of the completion choice.
      text (str): The completion response.
      logprobs (float, optional): The log probabilities of the most likely tokens.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    text: str
    logprobs: Optional[Union[LogProbs, NewLogProbs]] = None
    finish_reason: Optional[Literal["stop", "length", "error"]] = None
    raw_output: Optional[RawOutput] = None


class CompletionResponse(BaseModel, extra=extra_policy):
    """The response message from a /v1/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "text_completion".
      created (int): The Unix time in seconds when the response was generated.
      choices (List[Choice]): The list of generated completion choices.
    """

    id: str
    object: str = "text_completion"
    created: int
    model: str
    choices: List[Choice]
    usage: UsageInfo
    perf_metrics: Optional[Dict[str, Any]] = None


class CompletionResponseStreamChoice(BaseModel, extra=extra_policy):
    """A streamed completion choice.

    Attributes:
      index (int): The index of the completion choice.
      text (str): The completion response.
      logprobs (float, optional): The log probabilities of the most likely tokens.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    text: str
    logprobs: Optional[Union[LogProbs, NewLogProbs]] = None
    finish_reason: Optional[Literal["stop", "length", "error"]] = None


class CompletionStreamResponse(BaseModel, extra=extra_policy):
    """The streamed response message from a /v1/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "text_completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[CompletionResponseStreamChoice]):
        The list of streamed completion choices.
    """

    id: str
    object: str = "text_completion"
    created: int
    model: str
    choices: List[CompletionResponseStreamChoice]
    usage: Optional[UsageInfo] = None
    perf_metrics: Optional[Dict[str, Any]] = None


class Model(BaseModel, extra=extra_policy):
    """A model deployed to the Fireworks platform.

    Attributes:
      id (str): The model name.
      object (str): The object type, which is always "model".
      created (int): The Unix time in seconds when the model was generated.
      owned_by (str): The organization account owning the model
      kind (str): The kind of model
      supports_image_input: Whether the model supports chat
      supports_image_input: Whether the model supports image input
      support_tools: Whether the model supports tools
      context_length: The context length
    """

    id: str
    object: str = "model"
    created: int
    owned_by: str
    kind: Optional[str] = None
    supports_chat: bool = False
    supports_image_input: bool = False
    supports_tools: bool = False
    context_length: int = None


class ListModelsResponse(BaseModel, extra=extra_policy):
    """The response message from a /v1/models call.

    Attributes:
      object (str): The object type, which is always "list".
      data (List[Model]): The list of models.
    """

    object: str = "list"
    data: List[Model]


class ChatCompletionMessageToolCallFunction(BaseModel, extra=extra_policy):
    name: Optional[str] = None
    # arguments can be either a dictionary or a string
    arguments: Optional[Union[str, Dict[str, Any]]] = None


# TODO: maybe split the function for streaming into a different struct?
class ChatCompletionMessageToolCall(BaseModel, extra=extra_policy):
    # TODO: openai requires an index here, will default to zero since we can only
    # return 1 call right now
    index: int = 0
    id: Optional[str] = None
    type: str = "function"
    function: Union[ChatCompletionMessageToolCallFunction, str]


class ChatMessageContentImageURL(BaseModel, extra=extra_policy):
    url: str
    detail: Optional[str] = None


class ChatMessageContent(BaseModel, extra=extra_policy):
    type: StrictStr
    text: Optional[StrictStr] = None
    image_url: Optional[ChatMessageContentImageURL] = None


class ChatMessage(BaseModel, extra=extra_policy):
    """A chat completion message.

    Attributes:
      role (str): The role of the author of this message.
      content (str): The contents of the message.
      tool_calls (list[ChatCompletionMessageToolCall]): used by tools call to communicate the tools call information
      tool_call_id (str): used by tools call to identify which call it was
      name (str): Unused. For OpenAI compatability.
    """

    role: StrictStr
    content: Optional[Union[StrictStr, List[ChatMessageContent]]] = None
    reasoning_content: Optional[StrictStr] = None
    tool_calls: Optional[List[ChatCompletionMessageToolCall]] = None
    tool_call_id: Optional[StrictStr] = None
    function: Optional[ChatCompletionMessageToolCallFunction] = None
    name: Optional[StrictStr] = None

    def dict(self, *args, **kwargs) -> Dict[str, Any]:
        kwargs.pop("exclude_none", None)
        return super().dict(*args, exclude_none=True, **kwargs)


class ChatCompletionFunction(BaseModel, extra=extra_policy):
    name: StrictStr
    description: Optional[StrictStr] = None
    parameters: Dict[str, Any] = Field(default_factory=dict)
    strict: Optional[bool] = None


class ChatCompletionTool(BaseModel, extra=extra_policy):
    type: Literal["function"] = Field(
        ...,
        description="The type of the tool. Currently, only `function` is supported.",
    )
    function: ChatCompletionFunction


class ChatCompletionResponseChoice(BaseModel, extra=extra_policy):
    """A chat completion choice generated by a chat model.

    Attributes:
      index (int): The index of the chat completion choice.
      message (ChatMessage): The chat completion message.
      finish_reason (Optional[str]): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    message: ChatMessage
    finish_reason: Optional[str] = None
    # Extension of OpenAI API
    logprobs: Optional[Union[LogProbs, NewLogProbs]] = None
    raw_output: Optional[RawOutput] = None


class ChatCompletionResponse(BaseModel, extra=extra_policy):
    """The response message from a /v1/chat/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "chat.completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[ChatCompletionResponseChoice]): The list of chat completion choices.
      usage (UsageInfo): Usage statistics for the chat completion.
    """

    id: str
    object: str = "chat.completion"
    created: int
    model: str
    choices: List[ChatCompletionResponseChoice]
    # extension of OpenAI API
    usage: Optional[UsageInfo] = None
    perf_metrics: Optional[Dict[str, Any]] = None


class DeltaMessage(BaseModel, extra=extra_policy):
    """A message delta.

    Attributes:
      role (str): The role of the author of this message.
      content (str): The contents of the chunk message.
    """

    role: Optional[str] = None
    content: Optional[str] = None
    reasoning_content: Optional[str] = None
    tool_calls: Optional[List[ChatCompletionMessageToolCall]] = None
    function: Optional[str] = None


class ChatCompletionResponseStreamChoice(BaseModel, extra=extra_policy):
    """A streamed chat completion choice.

    Attributes:
      index (int): The index of the chat completion choice.
      delta (DeltaMessage): The message delta.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    delta: DeltaMessage
    finish_reason: Optional[Literal["stop", "length", "function_call", "tool_calls"]] = None
    # extension of OpenAI API
    logprobs: Optional[Union[LogProbs, NewLogProbs]] = None


class ChatCompletionStreamResponse(BaseModel, extra=extra_policy):
    """The streamed response message from a /v1/chat/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "chat.completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[ChatCompletionResponseStreamChoice]):
        The list of streamed chat completion choices.
    """

    id: str
    object: str = "chat.completion.chunk"
    created: int
    model: str
    choices: List[ChatCompletionResponseStreamChoice]
    usage: Optional[UsageInfo] = None
    perf_metrics: Optional[Dict[str, Any]] = None


class EmbeddingInfo(BaseModel, extra=extra_policy):
    index: int
    # List of floats or base64 encoded string
    embedding: Union[List[float], str]
    object: str = "embedding"
    raw_output: Optional[RawOutput] = None


class EmbeddingResponse(BaseModel, extra=extra_policy):
    """The response message from a /v1/embeddings call."""

    data: List[EmbeddingInfo]
    model: str
    usage: Optional[UsageInfo] = None
    perf_metrics: Optional[Dict[str, Any]] = None
    object: str = "list"


class Document(BaseModel, extra=extra_policy):
    """
    A list of document objects or strings to rerank.
    If a document is provided the text fields is required and all other fields will be preserved in the response.

    The total max chunks (length of documents * max_chunks_per_doc) must be less than 10000.

    We recommend a maximum of 1,000 documents for optimal endpoint performance.
    """

    index: int
    relevance_score: float
    text: Optional[str] = None


class RerankResponse(BaseModel, extra=extra_policy):
    """
    An ordered list of ranked documents
    """

    results: List[Document]


# Hugging Face TGI response formats.
class TgiGenerateTokenInfo(BaseModel, extra=extra_policy):
    """Information about a generated token.

    Attributes:
      id (int): The token ID.
      text (str): The token text.
      logprob (float): Log probability of the token.
      special (bool): Whether this is a special token.
    """

    id: int
    text: str
    logprob: float
    special: bool


class TgiGenerateDetails(BaseModel, extra=extra_policy):
    """Details about the text generation process.

    Attributes:
      finish_reason (str): The reason generation stopped.
      generated_tokens (int): Number of tokens generated.
      tokens (List[TgiGenerateTokenInfo]): Information about each generated token.
    """

    finish_reason: str
    generated_tokens: int
    tokens: List[TgiGenerateTokenInfo]


class TgiGenerateResponse(BaseModel, extra=extra_policy):
    """Response from text generation.

    Attributes:
      generated_text (str): The complete generated text.
      details (Optional[TgiGenerateDetails]): Additional details about the generation process.
    """

    id: Optional[str] = None
    object: str = "text_completion"
    created: Optional[int] = None
    model: Optional[str] = None
    generated_text: str
    details: Optional[TgiGenerateDetails] = None


class TgiGenerateStreamResponse(BaseModel, extra=extra_policy):
    """Streaming response for text generation.

    Attributes:
      token (TgiGenerateTokenInfo): Information about the current generated token.
      generated_text (Optional[str]): The text generated so far.
      details (Optional[TgiGenerateDetails]): Additional generation details.
      index (int): Position in the generation sequence.
    """

    id: Optional[str] = None
    object: str = "text_completion"
    created: Optional[int] = None
    model: Optional[str] = None
    token: Optional[TgiGenerateTokenInfo] = None
    generated_text: Optional[str] = None
    details: Optional[TgiGenerateDetails] = None
    index: int = 0



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/reservation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/reservation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/reservation.proto\x12\x07gateway\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x04\n\x0bReservation\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12%\n\x06region\x18\r \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x02\x12\x38\n\x10\x61\x63\x63\x65lerator_type\x18\x06 \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x02\x12\x1c\n\x0ereserved_count\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12,\n\x08\x63ontract\x18\x0c \x01(\tB\x1a\xe2\x41\x01\x02\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:|\xea\x41l\n\x1c\x61pi.fireworks.ai/Reservation\x12\x31\x61\x63\x63ounts/{AccountId}/reservations/{ReservationId}*\x0creservations2\x0breservation\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"+\n\x15GetReservationRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListReservationsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"s\n\x18ListReservationsResponse\x12*\n\x0creservations\x18\x01 \x03(\x0b\x32\x14.gateway.Reservation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.reservation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_RESERVATION'].fields_by_name['name']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['description']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['created_by']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_RESERVATION'].fields_by_name['region']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['region']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['reserved_count']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['reserved_count']._serialized_options = b'\342A\001\002'
  _globals['_RESERVATION'].fields_by_name['start_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['end_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION'].fields_by_name['contract']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['contract']._serialized_options = b'\342A\001\002\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_RESERVATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_RESERVATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_RESERVATION']._loaded_options = None
  _globals['_RESERVATION']._serialized_options = b'\352Al\n\034api.fireworks.ai/Reservation\0221accounts/{AccountId}/reservations/{ReservationId}*\014reservations2\013reservation\202\361\004\t\n\007Account'
  _globals['_GETRESERVATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETRESERVATIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTRESERVATIONSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_RESERVATION']._serialized_start=210
  _globals['_RESERVATION']._serialized_end=842
  _globals['_GETRESERVATIONREQUEST']._serialized_start=844
  _globals['_GETRESERVATIONREQUEST']._serialized_end=887
  _globals['_LISTRESERVATIONSREQUEST']._serialized_start=890
  _globals['_LISTRESERVATIONSREQUEST']._serialized_end=1034
  _globals['_LISTRESERVATIONSRESPONSE']._serialized_start=1036
  _globals['_LISTRESERVATIONSRESPONSE']._serialized_end=1151
# @@protoc_insertion_point(module_scope)



from ..buf.validate import validate_pb2 as _validate_pb2
from . import deployment_pb2 as _deployment_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from . import wandb_pb2 as _wandb_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SupervisedFineTuningJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "completed_time", "dataset", "state", "status", "created_by", "output_model", "base_model", "warm_start_from", "jinja_template", "early_stop", "epochs", "learning_rate", "max_context_length", "lora_rank", "base_model_weight_precision", "wandb_config", "evaluation_dataset", "accelerator_type", "accelerator_count", "is_turbo", "eval_auto_carveout", "region", "update_time", "nodes", "batch_size", "mtp_enabled", "mtp_num_draft_tokens", "mtp_freeze_base_model")
    class WeightPrecision(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        WEIGHT_PRECISION_UNSPECIFIED: _ClassVar[SupervisedFineTuningJob.WeightPrecision]
        BFLOAT16: _ClassVar[SupervisedFineTuningJob.WeightPrecision]
        INT8: _ClassVar[SupervisedFineTuningJob.WeightPrecision]
        NF4: _ClassVar[SupervisedFineTuningJob.WeightPrecision]
    WEIGHT_PRECISION_UNSPECIFIED: SupervisedFineTuningJob.WeightPrecision
    BFLOAT16: SupervisedFineTuningJob.WeightPrecision
    INT8: SupervisedFineTuningJob.WeightPrecision
    NF4: SupervisedFineTuningJob.WeightPrecision
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_TIME_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_MODEL_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    WARM_START_FROM_FIELD_NUMBER: _ClassVar[int]
    JINJA_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    EARLY_STOP_FIELD_NUMBER: _ClassVar[int]
    EPOCHS_FIELD_NUMBER: _ClassVar[int]
    LEARNING_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    LORA_RANK_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_WEIGHT_PRECISION_FIELD_NUMBER: _ClassVar[int]
    WANDB_CONFIG_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_DATASET_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    IS_TURBO_FIELD_NUMBER: _ClassVar[int]
    EVAL_AUTO_CARVEOUT_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    MTP_ENABLED_FIELD_NUMBER: _ClassVar[int]
    MTP_NUM_DRAFT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    MTP_FREEZE_BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    completed_time: _timestamp_pb2.Timestamp
    dataset: str
    state: _status_pb2.JobState
    status: _status_pb2.Status
    created_by: str
    output_model: str
    base_model: str
    warm_start_from: str
    jinja_template: str
    early_stop: bool
    epochs: int
    learning_rate: float
    max_context_length: int
    lora_rank: int
    base_model_weight_precision: SupervisedFineTuningJob.WeightPrecision
    wandb_config: _wandb_pb2.WandbConfig
    evaluation_dataset: str
    accelerator_type: _deployment_pb2.AcceleratorType
    accelerator_count: int
    is_turbo: bool
    eval_auto_carveout: bool
    region: _deployment_pb2.Region
    update_time: _timestamp_pb2.Timestamp
    nodes: int
    batch_size: int
    mtp_enabled: bool
    mtp_num_draft_tokens: int
    mtp_freeze_base_model: bool
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., dataset: _Optional[str] = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., created_by: _Optional[str] = ..., output_model: _Optional[str] = ..., base_model: _Optional[str] = ..., warm_start_from: _Optional[str] = ..., jinja_template: _Optional[str] = ..., early_stop: bool = ..., epochs: _Optional[int] = ..., learning_rate: _Optional[float] = ..., max_context_length: _Optional[int] = ..., lora_rank: _Optional[int] = ..., base_model_weight_precision: _Optional[_Union[SupervisedFineTuningJob.WeightPrecision, str]] = ..., wandb_config: _Optional[_Union[_wandb_pb2.WandbConfig, _Mapping]] = ..., evaluation_dataset: _Optional[str] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., accelerator_count: _Optional[int] = ..., is_turbo: bool = ..., eval_auto_carveout: bool = ..., region: _Optional[_Union[_deployment_pb2.Region, str]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., nodes: _Optional[int] = ..., batch_size: _Optional[int] = ..., mtp_enabled: bool = ..., mtp_num_draft_tokens: _Optional[int] = ..., mtp_freeze_base_model: bool = ...) -> None: ...

class GetSupervisedFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateSupervisedFineTuningJobRequest(_message.Message):
    __slots__ = ("parent", "supervised_fine_tuning_job", "debug", "supervised_fine_tuning_job_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SUPERVISED_FINE_TUNING_JOB_FIELD_NUMBER: _ClassVar[int]
    DEBUG_FIELD_NUMBER: _ClassVar[int]
    SUPERVISED_FINE_TUNING_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    supervised_fine_tuning_job: SupervisedFineTuningJob
    debug: bool
    supervised_fine_tuning_job_id: str
    def __init__(self, parent: _Optional[str] = ..., supervised_fine_tuning_job: _Optional[_Union[SupervisedFineTuningJob, _Mapping]] = ..., debug: bool = ..., supervised_fine_tuning_job_id: _Optional[str] = ...) -> None: ...

class ListSupervisedFineTuningJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListSupervisedFineTuningJobsResponse(_message.Message):
    __slots__ = ("supervised_fine_tuning_jobs", "next_page_token", "total_size")
    SUPERVISED_FINE_TUNING_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    supervised_fine_tuning_jobs: _containers.RepeatedCompositeFieldContainer[SupervisedFineTuningJob]
    next_page_token: str
    total_size: int
    def __init__(self, supervised_fine_tuning_jobs: _Optional[_Iterable[_Union[SupervisedFineTuningJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteSupervisedFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from .llm import LLM
from .dataset import Dataset
from .supervised_fine_tuning_job import SupervisedFineTuningJob
import importlib.metadata

try:
    __version__ = importlib.metadata.version(__name__)
except importlib.metadata.PackageNotFoundError:
    __version__ = "0.0.0"  # Fallback for development mode

__all__ = ["LLM", "Dataset", "SupervisedFineTuningJob", "__version__"]



from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ..google.type import money_pb2 as _money_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetBalanceRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class Balance(_message.Message):
    __slots__ = ("money",)
    MONEY_FIELD_NUMBER: _ClassVar[int]
    money: _money_pb2.Money
    def __init__(self, money: _Optional[_Union[_money_pb2.Money, _Mapping]] = ...) -> None: ...

class ListPaymentMethodsRequest(_message.Message):
    __slots__ = ("parent",)
    PARENT_FIELD_NUMBER: _ClassVar[int]
    parent: str
    def __init__(self, parent: _Optional[str] = ...) -> None: ...

class StripeCheckoutSession(_message.Message):
    __slots__ = ("id", "checkout_url", "mode", "amount", "create_time")
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MODE_UNSPECIFIED: _ClassVar[StripeCheckoutSession.Mode]
        PAYMENT: _ClassVar[StripeCheckoutSession.Mode]
        SETUP: _ClassVar[StripeCheckoutSession.Mode]
    MODE_UNSPECIFIED: StripeCheckoutSession.Mode
    PAYMENT: StripeCheckoutSession.Mode
    SETUP: StripeCheckoutSession.Mode
    ID_FIELD_NUMBER: _ClassVar[int]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    id: str
    checkout_url: str
    mode: StripeCheckoutSession.Mode
    amount: _money_pb2.Money
    create_time: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., checkout_url: _Optional[str] = ..., mode: _Optional[_Union[StripeCheckoutSession.Mode, str]] = ..., amount: _Optional[_Union[_money_pb2.Money, _Mapping]] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListPaymentMethodsResponse(_message.Message):
    __slots__ = ("default_payment_method_id", "stripe_payment_methods", "pending_checkout_sessions")
    class Card(_message.Message):
        __slots__ = ("brand", "last4", "exp_month", "exp_year")
        BRAND_FIELD_NUMBER: _ClassVar[int]
        LAST4_FIELD_NUMBER: _ClassVar[int]
        EXP_MONTH_FIELD_NUMBER: _ClassVar[int]
        EXP_YEAR_FIELD_NUMBER: _ClassVar[int]
        brand: str
        last4: str
        exp_month: int
        exp_year: int
        def __init__(self, brand: _Optional[str] = ..., last4: _Optional[str] = ..., exp_month: _Optional[int] = ..., exp_year: _Optional[int] = ...) -> None: ...
    class UsBankAccount(_message.Message):
        __slots__ = ("bank_name", "last4")
        BANK_NAME_FIELD_NUMBER: _ClassVar[int]
        LAST4_FIELD_NUMBER: _ClassVar[int]
        bank_name: str
        last4: str
        def __init__(self, bank_name: _Optional[str] = ..., last4: _Optional[str] = ...) -> None: ...
    class StripePaymentMethod(_message.Message):
        __slots__ = ("id", "card", "us_bank_account")
        ID_FIELD_NUMBER: _ClassVar[int]
        CARD_FIELD_NUMBER: _ClassVar[int]
        US_BANK_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
        id: str
        card: ListPaymentMethodsResponse.Card
        us_bank_account: ListPaymentMethodsResponse.UsBankAccount
        def __init__(self, id: _Optional[str] = ..., card: _Optional[_Union[ListPaymentMethodsResponse.Card, _Mapping]] = ..., us_bank_account: _Optional[_Union[ListPaymentMethodsResponse.UsBankAccount, _Mapping]] = ...) -> None: ...
    DEFAULT_PAYMENT_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    STRIPE_PAYMENT_METHODS_FIELD_NUMBER: _ClassVar[int]
    PENDING_CHECKOUT_SESSIONS_FIELD_NUMBER: _ClassVar[int]
    default_payment_method_id: str
    stripe_payment_methods: _containers.RepeatedCompositeFieldContainer[ListPaymentMethodsResponse.StripePaymentMethod]
    pending_checkout_sessions: _containers.RepeatedCompositeFieldContainer[StripeCheckoutSession]
    def __init__(self, default_payment_method_id: _Optional[str] = ..., stripe_payment_methods: _Optional[_Iterable[_Union[ListPaymentMethodsResponse.StripePaymentMethod, _Mapping]]] = ..., pending_checkout_sessions: _Optional[_Iterable[_Union[StripeCheckoutSession, _Mapping]]] = ...) -> None: ...

class ListCostsRequest(_message.Message):
    __slots__ = ("parent", "start_time", "end_time", "cumulative")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    CUMULATIVE_FIELD_NUMBER: _ClassVar[int]
    parent: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    cumulative: bool
    def __init__(self, parent: _Optional[str] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cumulative: bool = ...) -> None: ...

class ListCostsResponse(_message.Message):
    __slots__ = ("cost_data_items",)
    class CostDataItem(_message.Message):
        __slots__ = ("subtotal", "total", "start_time", "end_time")
        SUBTOTAL_FIELD_NUMBER: _ClassVar[int]
        TOTAL_FIELD_NUMBER: _ClassVar[int]
        START_TIME_FIELD_NUMBER: _ClassVar[int]
        END_TIME_FIELD_NUMBER: _ClassVar[int]
        subtotal: _money_pb2.Money
        total: _money_pb2.Money
        start_time: _timestamp_pb2.Timestamp
        end_time: _timestamp_pb2.Timestamp
        def __init__(self, subtotal: _Optional[_Union[_money_pb2.Money, _Mapping]] = ..., total: _Optional[_Union[_money_pb2.Money, _Mapping]] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    COST_DATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
    cost_data_items: _containers.RepeatedCompositeFieldContainer[ListCostsResponse.CostDataItem]
    def __init__(self, cost_data_items: _Optional[_Iterable[_Union[ListCostsResponse.CostDataItem, _Mapping]]] = ...) -> None: ...

class ListInvoicesRequest(_message.Message):
    __slots__ = ("parent", "pending", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PENDING_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    pending: bool
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., pending: bool = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class Invoice(_message.Message):
    __slots__ = ("id", "amount_due", "invoice_url", "state", "target_time", "paid_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Invoice.State]
        DRAFT: _ClassVar[Invoice.State]
        ISSUED: _ClassVar[Invoice.State]
        PAID: _ClassVar[Invoice.State]
        VOID: _ClassVar[Invoice.State]
        FAILED: _ClassVar[Invoice.State]
    STATE_UNSPECIFIED: Invoice.State
    DRAFT: Invoice.State
    ISSUED: Invoice.State
    PAID: Invoice.State
    VOID: Invoice.State
    FAILED: Invoice.State
    ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_DUE_FIELD_NUMBER: _ClassVar[int]
    INVOICE_URL_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    TARGET_TIME_FIELD_NUMBER: _ClassVar[int]
    PAID_TIME_FIELD_NUMBER: _ClassVar[int]
    id: str
    amount_due: _money_pb2.Money
    invoice_url: str
    state: Invoice.State
    target_time: _timestamp_pb2.Timestamp
    paid_time: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., amount_due: _Optional[_Union[_money_pb2.Money, _Mapping]] = ..., invoice_url: _Optional[str] = ..., state: _Optional[_Union[Invoice.State, str]] = ..., target_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., paid_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListInvoicesResponse(_message.Message):
    __slots__ = ("invoices", "next_page_token", "total_size")
    INVOICES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    invoices: _containers.RepeatedCompositeFieldContainer[Invoice]
    next_page_token: str
    total_size: int
    def __init__(self, invoices: _Optional[_Iterable[_Union[Invoice, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class SKUInfo(_message.Message):
    __slots__ = ("sku", "amount", "unit")
    SKU_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    sku: str
    amount: _money_pb2.Money
    unit: str
    def __init__(self, sku: _Optional[str] = ..., amount: _Optional[_Union[_money_pb2.Money, _Mapping]] = ..., unit: _Optional[str] = ...) -> None: ...

class ExportBillingMetricsRequest(_message.Message):
    __slots__ = ("name", "start_time", "end_time")
    NAME_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ExportBillingMetricsResponse(_message.Message):
    __slots__ = ("signed_urls",)
    SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    signed_urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, signed_urls: _Optional[_Iterable[str]] = ...) -> None: ...

class GetTotalHistoricalSpendRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetTotalHistoricalSpendResponse(_message.Message):
    __slots__ = ("spend",)
    SPEND_FIELD_NUMBER: _ClassVar[int]
    spend: _money_pb2.Money
    def __init__(self, spend: _Optional[_Union[_money_pb2.Money, _Mapping]] = ...) -> None: ...

class ListHuggingFaceBillingCostsRecords(_message.Message):
    __slots__ = ("parent", "request_ids")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_IDS_FIELD_NUMBER: _ClassVar[int]
    parent: str
    request_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parent: _Optional[str] = ..., request_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class BillingRequestCostRecord(_message.Message):
    __slots__ = ("request_id", "cost_nano_usd")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    COST_NANO_USD_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    cost_nano_usd: float
    def __init__(self, request_id: _Optional[str] = ..., cost_nano_usd: _Optional[float] = ...) -> None: ...

class ListHuggingFaceBillingCostsResponse(_message.Message):
    __slots__ = ("requests",)
    REQUESTS_FIELD_NUMBER: _ClassVar[int]
    requests: _containers.RepeatedCompositeFieldContainer[BillingRequestCostRecord]
    def __init__(self, requests: _Optional[_Iterable[_Union[BillingRequestCostRecord, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/quota.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/quota.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/quota.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x02\n\x05Quota\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\r\n\x05value\x18\x02 \x01(\x03\x12\x11\n\tmax_value\x18\x03 \x01(\x03\x12\x35\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12K\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1a\xe2\x41\x01\x03\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY:^\xea\x41N\n\x16\x61pi.fireworks.ai/Quota\x12%accounts/{AccountId}/quotas/{QuotaId}*\x06quotas2\x05quota\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"%\n\x0fGetQuotaRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8a\x01\n\x11ListQuotasRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x12UpdateQuotaRequest\x12#\n\x05quota\x18\x01 \x01(\x0b\x32\x0e.gateway.QuotaB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"a\n\x12ListQuotasResponse\x12\x1e\n\x06quotas\x18\x01 \x03(\x0b\x32\x0e.gateway.Quota\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.quota_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_QUOTA'].fields_by_name['name']._loaded_options = None
  _globals['_QUOTA'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_QUOTA'].fields_by_name['update_time']._loaded_options = None
  _globals['_QUOTA'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_QUOTA'].fields_by_name['create_time']._loaded_options = None
  _globals['_QUOTA'].fields_by_name['create_time']._serialized_options = b'\342A\001\003\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_QUOTA']._loaded_options = None
  _globals['_QUOTA']._serialized_options = b'\352AN\n\026api.fireworks.ai/Quota\022%accounts/{AccountId}/quotas/{QuotaId}*\006quotas2\005quota\202\361\004\t\n\007Account'
  _globals['_GETQUOTAREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETQUOTAREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTQUOTASREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTQUOTASREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTQUOTASREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTASREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTQUOTASREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTASREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTQUOTASREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTQUOTASREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTQUOTASREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTQUOTASREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEQUOTAREQUEST'].fields_by_name['quota']._loaded_options = None
  _globals['_UPDATEQUOTAREQUEST'].fields_by_name['quota']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEQUOTAREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEQUOTAREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_QUOTA']._serialized_start=212
  _globals['_QUOTA']._serialized_end=502
  _globals['_GETQUOTAREQUEST']._serialized_start=504
  _globals['_GETQUOTAREQUEST']._serialized_end=541
  _globals['_LISTQUOTASREQUEST']._serialized_start=544
  _globals['_LISTQUOTASREQUEST']._serialized_end=682
  _globals['_UPDATEQUOTAREQUEST']._serialized_start=684
  _globals['_UPDATEQUOTAREQUEST']._serialized_end=796
  _globals['_LISTQUOTASRESPONSE']._serialized_start=798
  _globals['_LISTQUOTASRESPONSE']._serialized_end=895
# @@protoc_insertion_point(module_scope)



from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AwsIamRoleBinding(_message.Message):
    __slots__ = ("account_id", "create_time", "principal", "role")
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    create_time: _timestamp_pb2.Timestamp
    principal: str
    role: str
    def __init__(self, account_id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., principal: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class CreateAwsIamRoleBindingRequest(_message.Message):
    __slots__ = ("parent", "aws_iam_role_binding")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    AWS_IAM_ROLE_BINDING_FIELD_NUMBER: _ClassVar[int]
    parent: str
    aws_iam_role_binding: AwsIamRoleBinding
    def __init__(self, parent: _Optional[str] = ..., aws_iam_role_binding: _Optional[_Union[AwsIamRoleBinding, _Mapping]] = ...) -> None: ...

class ListAwsIamRoleBindingsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListAwsIamRoleBindingsResponse(_message.Message):
    __slots__ = ("aws_iam_role_bindings", "next_page_token", "total_size")
    AWS_IAM_ROLE_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    aws_iam_role_bindings: _containers.RepeatedCompositeFieldContainer[AwsIamRoleBinding]
    next_page_token: str
    total_size: int
    def __init__(self, aws_iam_role_bindings: _Optional[_Iterable[_Union[AwsIamRoleBinding, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteAwsIamRoleBindingRequest(_message.Message):
    __slots__ = ("aws_iam_role_binding",)
    AWS_IAM_ROLE_BINDING_FIELD_NUMBER: _ClassVar[int]
    aws_iam_role_binding: AwsIamRoleBinding
    def __init__(self, aws_iam_role_binding: _Optional[_Union[AwsIamRoleBinding, _Mapping]] = ...) -> None: ...



from . import options_pb2 as _options_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EvaluatorState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STATE_UNSPECIFIED: _ClassVar[EvaluatorState]
    ACTIVE: _ClassVar[EvaluatorState]
STATE_UNSPECIFIED: EvaluatorState
ACTIVE: EvaluatorState

class Evaluator(_message.Message):
    __slots__ = ("name", "display_name", "description", "create_time", "created_by", "update_time", "state", "multi_metrics", "criteria", "requirements", "rollup_settings")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    MULTI_METRICS_FIELD_NUMBER: _ClassVar[int]
    CRITERIA_FIELD_NUMBER: _ClassVar[int]
    REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    ROLLUP_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    description: str
    create_time: _timestamp_pb2.Timestamp
    created_by: str
    update_time: _timestamp_pb2.Timestamp
    state: EvaluatorState
    multi_metrics: bool
    criteria: _containers.RepeatedCompositeFieldContainer[Criterion]
    requirements: str
    rollup_settings: RollupSettings
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[EvaluatorState, str]] = ..., multi_metrics: bool = ..., criteria: _Optional[_Iterable[_Union[Criterion, _Mapping]]] = ..., requirements: _Optional[str] = ..., rollup_settings: _Optional[_Union[RollupSettings, _Mapping]] = ...) -> None: ...

class Criterion(_message.Message):
    __slots__ = ("type", "name", "description", "code_snippets")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TYPE_UNSPECIFIED: _ClassVar[Criterion.Type]
        CODE_SNIPPETS: _ClassVar[Criterion.Type]
    TYPE_UNSPECIFIED: Criterion.Type
    CODE_SNIPPETS: Criterion.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_SNIPPETS_FIELD_NUMBER: _ClassVar[int]
    type: Criterion.Type
    name: str
    description: str
    code_snippets: CodeSnippets
    def __init__(self, type: _Optional[_Union[Criterion.Type, str]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code_snippets: _Optional[_Union[CodeSnippets, _Mapping]] = ...) -> None: ...

class CodeSnippets(_message.Message):
    __slots__ = ("language", "file_contents")
    class FileContentsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    FILE_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    language: str
    file_contents: _containers.ScalarMap[str, str]
    def __init__(self, language: _Optional[str] = ..., file_contents: _Optional[_Mapping[str, str]] = ...) -> None: ...

class RollupSettings(_message.Message):
    __slots__ = ("criteria_weights", "python_code", "success_threshold", "skip_rollup")
    class CriteriaWeightsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: float
        def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
    CRITERIA_WEIGHTS_FIELD_NUMBER: _ClassVar[int]
    PYTHON_CODE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SKIP_ROLLUP_FIELD_NUMBER: _ClassVar[int]
    criteria_weights: _containers.ScalarMap[str, float]
    python_code: str
    success_threshold: float
    skip_rollup: bool
    def __init__(self, criteria_weights: _Optional[_Mapping[str, float]] = ..., python_code: _Optional[str] = ..., success_threshold: _Optional[float] = ..., skip_rollup: bool = ...) -> None: ...

class GetEvaluatorRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListEvaluatorsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListEvaluatorsResponse(_message.Message):
    __slots__ = ("evaluators", "next_page_token", "total_size")
    EVALUATORS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    evaluators: _containers.RepeatedCompositeFieldContainer[Evaluator]
    next_page_token: str
    total_size: int
    def __init__(self, evaluators: _Optional[_Iterable[_Union[Evaluator, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class CreateEvaluatorRequest(_message.Message):
    __slots__ = ("parent", "evaluator", "evaluator_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    EVALUATOR_FIELD_NUMBER: _ClassVar[int]
    EVALUATOR_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    evaluator: Evaluator
    evaluator_id: str
    def __init__(self, parent: _Optional[str] = ..., evaluator: _Optional[_Union[Evaluator, _Mapping]] = ..., evaluator_id: _Optional[str] = ...) -> None: ...

class DeleteEvaluatorRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class PreviewEvaluatorRequest(_message.Message):
    __slots__ = ("evaluator", "sample_data", "max_samples", "parent")
    EVALUATOR_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_DATA_FIELD_NUMBER: _ClassVar[int]
    MAX_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    PARENT_FIELD_NUMBER: _ClassVar[int]
    evaluator: Evaluator
    sample_data: _containers.RepeatedScalarFieldContainer[str]
    max_samples: int
    parent: str
    def __init__(self, evaluator: _Optional[_Union[Evaluator, _Mapping]] = ..., sample_data: _Optional[_Iterable[str]] = ..., max_samples: _Optional[int] = ..., parent: _Optional[str] = ...) -> None: ...

class PreviewEvaluatorSampleResult(_message.Message):
    __slots__ = ("success", "score", "per_metric_evals")
    class PerMetricEvalsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Struct
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    PER_METRIC_EVALS_FIELD_NUMBER: _ClassVar[int]
    success: str
    score: float
    per_metric_evals: _containers.MessageMap[str, _struct_pb2.Struct]
    def __init__(self, success: _Optional[str] = ..., score: _Optional[float] = ..., per_metric_evals: _Optional[_Mapping[str, _struct_pb2.Struct]] = ...) -> None: ...

class PreviewEvaluatorResponse(_message.Message):
    __slots__ = ("results", "total_samples", "total_runtime_ms", "stdout", "stderr")
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    TOTAL_RUNTIME_MS_FIELD_NUMBER: _ClassVar[int]
    STDOUT_FIELD_NUMBER: _ClassVar[int]
    STDERR_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[PreviewEvaluatorSampleResult]
    total_samples: int
    total_runtime_ms: int
    stdout: _containers.RepeatedScalarFieldContainer[str]
    stderr: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, results: _Optional[_Iterable[_Union[PreviewEvaluatorSampleResult, _Mapping]]] = ..., total_samples: _Optional[int] = ..., total_runtime_ms: _Optional[int] = ..., stdout: _Optional[_Iterable[str]] = ..., stderr: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/cluster.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8c\x06\n\x07\x43luster\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12*\n\x0b\x65ks_cluster\x18\x07 \x01(\x0b\x32\x13.gateway.EksClusterH\x00\x12,\n\x0c\x66\x61ke_cluster\x18\x03 \x01(\x0b\x32\x14.gateway.FakeClusterH\x00\x12M\n\x0b\x61nnotations\x18\n \x03(\x0b\x32!.gateway.Cluster.AnnotationsEntryB\x15\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12,\n\x05state\x18\x05 \x01(\x0e\x32\x16.gateway.Cluster.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12,\n\x07is_dlde\x18\x0b \x01(\x08\x42\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x31\n\x0cmetering_key\x18\r \x01(\tB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04:j\xea\x41X\n\x18\x61pi.fireworks.ai/Cluster\x12)accounts/{AccountId}/clusters/{ClusterId}*\x08\x63lusters2\x07\x63luster\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\x0e\n\x0c\x63luster_type\"\xf8\x04\n\nEksCluster\x12\x1d\n\x0e\x61ws_account_id\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12%\n\x16\x66ireworks_manager_role\x18\x01 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x15\n\x06region\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12,\n\x0c\x63luster_role\x18\x04 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x37\n\x17\x63luster_autoscaler_role\x18\n \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x30\n\x10system_node_role\x18\x07 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12*\n\nsubnet_ids\x18\x05 \x03(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\x1b\n\x0c\x63luster_name\x18\x03 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12/\n\x0frepository_name\x18\x06 \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12\"\n\x13storage_bucket_name\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x33\n\x13node_security_group\x18\x0b \x01(\tB\x16\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x0b\x12\tDLDE_ONLY\x12!\n\x12metric_writer_role\x18\x0c \x01(\tB\x05\xe2\x41\x02\x01\x05\x12,\n\x1dload_balancer_controller_role\x18\r \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x31\n\"workload_identity_pool_provider_id\x18\x0e \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1d\n\x0einference_role\x18\x0f \x01(\tB\x05\xe2\x41\x02\x01\x05\"I\n\x0b\x46\x61keCluster\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"o\n\x14\x43reateClusterRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.gateway.ClusterB\x04\xe2\x41\x01\x02\x12\x18\n\ncluster_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"\'\n\x11GetClusterRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8c\x01\n\x13ListClustersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"g\n\x14ListClustersResponse\x12\"\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x10.gateway.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"v\n\x14UpdateClusterRequest\x12\'\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.gateway.ClusterB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"*\n\x14\x44\x65leteClusterRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"5\n\x1fGetClusterConnectionInfoRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\":\n\x15\x43lusterConnectionInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_data\x18\x02 \x01(\tBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_CLUSTER_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['name']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['display_name']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_CLUSTER'].fields_by_name['create_time']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['annotations']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['annotations']._serialized_options = b'\342A\001\001\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_CLUSTER'].fields_by_name['state']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['status']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_CLUSTER'].fields_by_name['is_dlde']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['is_dlde']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CLUSTER'].fields_by_name['metering_key']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['metering_key']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_CLUSTER'].fields_by_name['update_time']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_CLUSTER']._loaded_options = None
  _globals['_CLUSTER']._serialized_options = b'\352AX\n\030api.fireworks.ai/Cluster\022)accounts/{AccountId}/clusters/{ClusterId}*\010clusters2\007cluster\202\361\004\013\n\007Account\030\001'
  _globals['_EKSCLUSTER'].fields_by_name['aws_account_id']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['aws_account_id']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSCLUSTER'].fields_by_name['fireworks_manager_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['fireworks_manager_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['region']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['region']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_autoscaler_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_autoscaler_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['system_node_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['system_node_role']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['subnet_ids']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['cluster_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['cluster_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['repository_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['repository_name']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['storage_bucket_name']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['storage_bucket_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['node_security_group']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['node_security_group']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\013\022\tDLDE_ONLY'
  _globals['_EKSCLUSTER'].fields_by_name['metric_writer_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['metric_writer_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['load_balancer_controller_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['load_balancer_controller_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['workload_identity_pool_provider_id']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['workload_identity_pool_provider_id']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSCLUSTER'].fields_by_name['inference_role']._loaded_options = None
  _globals['_EKSCLUSTER'].fields_by_name['inference_role']._serialized_options = b'\342A\002\001\005'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\002'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\342A\001\002'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster']._serialized_options = b'\342A\001\002'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CLUSTER']._serialized_start=236
  _globals['_CLUSTER']._serialized_end=1016
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_start=759
  _globals['_CLUSTER_ANNOTATIONSENTRY']._serialized_end=809
  _globals['_CLUSTER_STATE']._serialized_start=811
  _globals['_CLUSTER_STATE']._serialized_end=892
  _globals['_EKSCLUSTER']._serialized_start=1019
  _globals['_EKSCLUSTER']._serialized_end=1651
  _globals['_FAKECLUSTER']._serialized_start=1653
  _globals['_FAKECLUSTER']._serialized_end=1726
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1728
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1839
  _globals['_GETCLUSTERREQUEST']._serialized_start=1841
  _globals['_GETCLUSTERREQUEST']._serialized_end=1880
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=1883
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=2023
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=2025
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=2128
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2130
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2248
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2250
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2292
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST']._serialized_start=2294
  _globals['_GETCLUSTERCONNECTIONINFOREQUEST']._serialized_end=2347
  _globals['_CLUSTERCONNECTIONINFO']._serialized_start=2349
  _globals['_CLUSTERCONNECTIONINFO']._serialized_end=2407
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/evaluator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/evaluator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/evaluator.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x04\n\tEvaluator\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12-\n\x05state\x18\x07 \x01(\x0e\x32\x17.gateway.EvaluatorStateB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\rmulti_metrics\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x05\x12*\n\x08\x63riteria\x18\t \x03(\x0b\x32\x12.gateway.CriterionB\x04\xe2\x41\x01\x05\x12\x1a\n\x0crequirements\x18\n \x01(\tB\x04\xe2\x41\x01\x01\x12;\n\x0frollup_settings\x18\x0b \x01(\x0b\x32\x17.gateway.RollupSettingsB\t\xe2\x41\x02\x05\x01\xa0\xf1\x04\x01:t\xea\x41\x62\n\x1a\x61pi.fireworks.ai/Evaluator\x12-accounts/{AccountId}/evaluators/{EvaluatorId}*\nEvaluators2\tEvaluator\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xb4\x01\n\tCriterion\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.gateway.Criterion.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12,\n\rcode_snippets\x18\x04 \x01(\x0b\x32\x15.gateway.CodeSnippets\"/\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rCODE_SNIPPETS\x10\x01\"\x95\x01\n\x0c\x43odeSnippets\x12\x10\n\x08language\x18\x01 \x01(\t\x12>\n\rfile_contents\x18\x02 \x03(\x0b\x32\'.gateway.CodeSnippets.FileContentsEntry\x1a\x33\n\x11\x46ileContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xed\x01\n\x0eRollupSettings\x12L\n\x10\x63riteria_weights\x18\x01 \x03(\x0b\x32,.gateway.RollupSettings.CriteriaWeightsEntryB\x04\xe2\x41\x01\x01\x12\x19\n\x0bpython_code\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1f\n\x11success_threshold\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x01\x12\x19\n\x0bskip_rollup\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a\x36\n\x14\x43riteriaWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\")\n\x13GetEvaluatorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8e\x01\n\x15ListEvaluatorsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"m\n\x16ListEvaluatorsResponse\x12&\n\nevaluators\x18\x01 \x03(\x0b\x32\x12.gateway.Evaluator\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"w\n\x16\x43reateEvaluatorRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12+\n\tevaluator\x18\x02 \x01(\x0b\x32\x12.gateway.EvaluatorB\x04\xe2\x41\x01\x02\x12\x1a\n\x0c\x65valuator_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\",\n\x16\x44\x65leteEvaluatorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x92\x01\n\x17PreviewEvaluatorRequest\x12+\n\tevaluator\x18\x01 \x01(\x0b\x32\x12.gateway.EvaluatorB\x04\xe2\x41\x01\x02\x12\x19\n\x0bsample_data\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0bmax_samples\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x14\n\x06parent\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\"\xe3\x01\n\x1cPreviewEvaluatorSampleResult\x12\x0f\n\x07success\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x12S\n\x10per_metric_evals\x18\x03 \x03(\x0b\x32\x39.gateway.PreviewEvaluatorSampleResult.PerMetricEvalsEntry\x1aN\n\x13PerMetricEvalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"\xa3\x01\n\x18PreviewEvaluatorResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.gateway.PreviewEvaluatorSampleResult\x12\x15\n\rtotal_samples\x18\x02 \x01(\x05\x12\x18\n\x10total_runtime_ms\x18\x03 \x01(\x03\x12\x0e\n\x06stdout\x18\x04 \x03(\t\x12\x0e\n\x06stderr\x18\x05 \x03(\t*3\n\x0e\x45valuatorState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.evaluator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EVALUATOR'].fields_by_name['name']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['create_time']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['created_by']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['update_time']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATOR'].fields_by_name['state']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATOR'].fields_by_name['multi_metrics']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['multi_metrics']._serialized_options = b'\342A\001\005'
  _globals['_EVALUATOR'].fields_by_name['criteria']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['criteria']._serialized_options = b'\342A\001\005'
  _globals['_EVALUATOR'].fields_by_name['requirements']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['requirements']._serialized_options = b'\342A\001\001'
  _globals['_EVALUATOR'].fields_by_name['rollup_settings']._loaded_options = None
  _globals['_EVALUATOR'].fields_by_name['rollup_settings']._serialized_options = b'\342A\002\005\001\240\361\004\001'
  _globals['_EVALUATOR']._loaded_options = None
  _globals['_EVALUATOR']._serialized_options = b'\352Ab\n\032api.fireworks.ai/Evaluator\022-accounts/{AccountId}/evaluators/{EvaluatorId}*\nEvaluators2\tEvaluator\202\361\004\013\n\007Account\030\001'
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._loaded_options = None
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_options = b'8\001'
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._loaded_options = None
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['criteria_weights']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['criteria_weights']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['python_code']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['python_code']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['success_threshold']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['success_threshold']._serialized_options = b'\342A\001\001'
  _globals['_ROLLUPSETTINGS'].fields_by_name['skip_rollup']._loaded_options = None
  _globals['_ROLLUPSETTINGS'].fields_by_name['skip_rollup']._serialized_options = b'\342A\001\001'
  _globals['_GETEVALUATORREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEVALUATORREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEVALUATORSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator_id']._loaded_options = None
  _globals['_CREATEEVALUATORREQUEST'].fields_by_name['evaluator_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEVALUATORREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEVALUATORREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['evaluator']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['evaluator']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['sample_data']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['sample_data']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['max_samples']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['max_samples']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_PREVIEWEVALUATORREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._loaded_options = None
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATORSTATE']._serialized_start=2311
  _globals['_EVALUATORSTATE']._serialized_end=2362
  _globals['_EVALUATOR']._serialized_start=183
  _globals['_EVALUATOR']._serialized_end=723
  _globals['_CRITERION']._serialized_start=726
  _globals['_CRITERION']._serialized_end=906
  _globals['_CRITERION_TYPE']._serialized_start=859
  _globals['_CRITERION_TYPE']._serialized_end=906
  _globals['_CODESNIPPETS']._serialized_start=909
  _globals['_CODESNIPPETS']._serialized_end=1058
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_start=1007
  _globals['_CODESNIPPETS_FILECONTENTSENTRY']._serialized_end=1058
  _globals['_ROLLUPSETTINGS']._serialized_start=1061
  _globals['_ROLLUPSETTINGS']._serialized_end=1298
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_start=1244
  _globals['_ROLLUPSETTINGS_CRITERIAWEIGHTSENTRY']._serialized_end=1298
  _globals['_GETEVALUATORREQUEST']._serialized_start=1300
  _globals['_GETEVALUATORREQUEST']._serialized_end=1341
  _globals['_LISTEVALUATORSREQUEST']._serialized_start=1344
  _globals['_LISTEVALUATORSREQUEST']._serialized_end=1486
  _globals['_LISTEVALUATORSRESPONSE']._serialized_start=1488
  _globals['_LISTEVALUATORSRESPONSE']._serialized_end=1597
  _globals['_CREATEEVALUATORREQUEST']._serialized_start=1599
  _globals['_CREATEEVALUATORREQUEST']._serialized_end=1718
  _globals['_DELETEEVALUATORREQUEST']._serialized_start=1720
  _globals['_DELETEEVALUATORREQUEST']._serialized_end=1764
  _globals['_PREVIEWEVALUATORREQUEST']._serialized_start=1767
  _globals['_PREVIEWEVALUATORREQUEST']._serialized_end=1913
  _globals['_PREVIEWEVALUATORSAMPLERESULT']._serialized_start=1916
  _globals['_PREVIEWEVALUATORSAMPLERESULT']._serialized_end=2143
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_start=2065
  _globals['_PREVIEWEVALUATORSAMPLERESULT_PERMETRICEVALSENTRY']._serialized_end=2143
  _globals['_PREVIEWEVALUATORRESPONSE']._serialized_start=2146
  _globals['_PREVIEWEVALUATORRESPONSE']._serialized_end=2309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/alert_rule.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/alert_rule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/alert_rule.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x03\n\tAlertRule\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x18\x61lert_rule_configuration\x18\x02 \x01(\tB\x05\xe2\x41\x02\x05\x02\x12\x17\n\tthreshold\x18\x03 \x01(\x01\x42\x04\xe2\x41\x01\x02\x12\x16\n\x08\x64uration\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x02\x12&\n\x07\x66ilters\x18\x06 \x03(\x0b\x32\x0f.gateway.FilterB\x04\xe2\x41\x01\x01\x12#\n\x15notification_channels\x18\x07 \x03(\tB\x04\xe2\x41\x01\x01\x12\x35\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\x92\x01\xea\x41}\n\x1a\x61pi.fireworks.ai/AlertRule\x12Haccounts/{AccountId}/deployments/{DeploymentId}/alertRules/{AlertRuleId}*\nalertRules2\talertRule\x82\xf1\x04\x0e\n\nDeployment\x18\x01\"\xe9\x01\n\x06\x46ilter\x12\x11\n\x03key\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x30\n\x08operator\x18\x03 \x01(\x0e\x32\x18.gateway.Filter.OperatorB\x04\xe2\x41\x01\x02\"\x84\x01\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x0f\n\x0b\x45QUAL_REGEX\x10\x03\x12\x13\n\x0fNOT_EQUAL_REGEX\x10\x04\x12\x0c\n\x08\x43ONTAINS\x10\x05\x12\x10\n\x0cNOT_CONTAINS\x10\x06\"\x85\x07\n\x16\x41lertRuleConfiguration\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x38\n\x04kind\x18\x02 \x01(\x0e\x32$.gateway.AlertRuleConfiguration.KindB\x04\xe2\x41\x01\x02\x12p\n\x1fmonitoring_policy_configuration\x18\x03 \x01(\x0b\x32=.gateway.AlertRuleConfiguration.MonitoringPolicyConfigurationB\x08\xe2\x41\x01\x02\xa0\xf1\x04\x01\x12\x35\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\xbc\x02\n\x1dMonitoringPolicyConfiguration\x12\x1b\n\rdocumentation\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08\x63ombiner\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07\x61ligner\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\ncomparison\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1e\n\x10\x61lignment_period\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\nexpression\x18\x07 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08severity\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01\x12#\n\x15notification_channels\x18\t \x03(\tB\x04\xe2\x41\x01\x01\x12\"\n\x14\x64\x65ployment_label_key\x18\n \x01(\tB\x04\xe2\x41\x01\x01\"d\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x14\n\x10MISSING_REPLICAS\x10\x01\x12\x14\n\x10HIGH_ERROR_COUNT\x10\x02\x12\x1a\n\x16HIGH_PERPLEXITY_OUTPUT\x10\x03:\x96\x01\xea\x41\x8e\x01\n\'api.fireworks.ai/AlertRuleConfiguration\x12\x32\x61lertRuleConfigurations/{AlertRuleConfigurationId}*\x17\x61lertRuleConfigurations2\x16\x61lertRuleConfiguration\x82\xf1\x04\x00\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.alert_rule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ALERTRULE'].fields_by_name['name']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ALERTRULE'].fields_by_name['alert_rule_configuration']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['alert_rule_configuration']._serialized_options = b'\342A\002\005\002'
  _globals['_ALERTRULE'].fields_by_name['threshold']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['threshold']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['duration']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['duration']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['enabled']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['enabled']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULE'].fields_by_name['filters']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['filters']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULE'].fields_by_name['notification_channels']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['notification_channels']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULE'].fields_by_name['create_time']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULE'].fields_by_name['update_time']._loaded_options = None
  _globals['_ALERTRULE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULE']._loaded_options = None
  _globals['_ALERTRULE']._serialized_options = b'\352A}\n\032api.fireworks.ai/AlertRule\022Haccounts/{AccountId}/deployments/{DeploymentId}/alertRules/{AlertRuleId}*\nalertRules2\talertRule\202\361\004\016\n\nDeployment\030\001'
  _globals['_FILTER'].fields_by_name['key']._loaded_options = None
  _globals['_FILTER'].fields_by_name['key']._serialized_options = b'\342A\001\002'
  _globals['_FILTER'].fields_by_name['value']._loaded_options = None
  _globals['_FILTER'].fields_by_name['value']._serialized_options = b'\342A\001\002'
  _globals['_FILTER'].fields_by_name['operator']._loaded_options = None
  _globals['_FILTER'].fields_by_name['operator']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['documentation']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['documentation']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['display_name']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['combiner']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['combiner']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['aligner']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['aligner']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['comparison']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['comparison']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['alignment_period']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['alignment_period']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['expression']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['expression']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['severity']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['severity']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['notification_channels']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['notification_channels']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['deployment_label_key']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION'].fields_by_name['deployment_label_key']._serialized_options = b'\342A\001\001'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['name']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['kind']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['kind']._serialized_options = b'\342A\001\002'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['monitoring_policy_configuration']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['monitoring_policy_configuration']._serialized_options = b'\342A\001\002\240\361\004\001'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ALERTRULECONFIGURATION']._loaded_options = None
  _globals['_ALERTRULECONFIGURATION']._serialized_options = b'\352A\216\001\n\'api.fireworks.ai/AlertRuleConfiguration\0222alertRuleConfigurations/{AlertRuleConfigurationId}*\027alertRuleConfigurations2\026alertRuleConfiguration\202\361\004\000'
  _globals['_ALERTRULE']._serialized_start=154
  _globals['_ALERTRULE']._serialized_end=635
  _globals['_FILTER']._serialized_start=638
  _globals['_FILTER']._serialized_end=871
  _globals['_FILTER_OPERATOR']._serialized_start=739
  _globals['_FILTER_OPERATOR']._serialized_end=871
  _globals['_ALERTRULECONFIGURATION']._serialized_start=874
  _globals['_ALERTRULECONFIGURATION']._serialized_end=1775
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION']._serialized_start=1204
  _globals['_ALERTRULECONFIGURATION_MONITORINGPOLICYCONFIGURATION']._serialized_end=1520
  _globals['_ALERTRULECONFIGURATION_KIND']._serialized_start=1522
  _globals['_ALERTRULECONFIGURATION_KIND']._serialized_end=1622
# @@protoc_insertion_point(module_scope)
